@@ -1,7 +1,7 @@
 /*
-  $Id: util.c,v 1.2 2003/10/28 16:23:50 rocky Exp $
+  $Id: util.c,v 1.4 2004/02/07 02:40:20 rocky Exp $
 
-  Copyright (C) 2003 Rocky Bernstein <rocky@panix.com>
+  Copyright (C) 2003, 2004 Rocky Bernstein <rocky@panix.com>
   
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -29,20 +29,21 @@ char *program_name;
 void 
 myexit(CdIo *cdio, int rc) 
 {
-  if (NULL != cdio) 
-    cdio_destroy(cdio);
+  if (NULL != cdio) cdio_destroy(cdio);
+  if (NULL != program_name) free(program_name);
+  if (NULL != source_name)  free(source_name);
   exit(rc);
 }
 
 void
-print_version (const char *program_name, const char *version, 
+print_version (char *program_name, const char *version, 
 	       int no_header, bool version_only)
 {
   
   driver_id_t driver_id;
 
   if (no_header == 0)
-    printf( "%s version %s\nCopyright (c) 2003 R. Bernstein\n",
+    printf( "%s version %s\nCopyright (c) 2003, 2004 R. Bernstein\n",
 	    program_name, version);
   printf( _("This is free software; see the source for copying conditions.\n\
 There is NO warranty; not even for MERCHANTABILITY or FITNESS FOR A\n\
@@ -61,6 +62,7 @@ PARTICULAR PURPOSE.\n\
       printf("Default CD-ROM device: %s\n", default_device);
     else
       printf("No CD-ROM device found.\n");
+    free(program_name);
     exit(100);
   }
   
